Package: MicrobiomeProfiler
Title: An R/shiny package for microbiome functional enrichment analysis
Version: 1.17.0
Authors@R: c(
    person(given = "Guangchuang", family = "Yu", email = "guangchuangyu@gmail.com", role  = c("cre", "aut"), comment = c(ORCID = "0000-0002-6485-8781")),
    person(given = "Meijun",family = "Chen", role = "aut", email = "mjchen1996@outlook.com", comment = c(ORCID = "0000-0003-2486-8106"))    
    )
Description: This is an R/shiny package to perform functional enrichment analysis for microbiome data. 
             This package was based on clusterProfiler. Moreover, MicrobiomeProfiler support KEGG enrichment analysis,
             COG enrichment analysis, Microbe-Disease association enrichment analysis, Metabo-Pathway analysis.
License: GPL-2
Depends: R (>= 4.2.0)
Imports: clusterProfiler (>= 4.5.2), config, DT, enrichplot, golem,
        gson, methods, magrittr, shiny (>= 1.6.0), shinyWidgets,
        shinycustomloader, htmltools, ggplot2, graphics, stats, utils,
        yulab.utils
Suggests: rmarkdown, knitr, testthat (>= 3.0.0), prettydoc
Encoding: UTF-8
biocViews: Microbiome, Software, Visualization,KEGG
RoxygenNote: 7.3.2
URL: https://github.com/YuLab-SMU/MicrobiomeProfiler/,
        https://yulab-smu.top/contribution-knowledge-mining/
BugReports: https://github.com/YuLab-SMU/MicrobiomeProfiler/issues
Config/testthat/edition: 3
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/MicrobiomeProfiler
git_branch: devel
git_last_commit: ef6d1ed
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-31
NeedsCompilation: no
Packaged: 2025-10-31 22:49:05 UTC; biocbuild
Author: Guangchuang Yu [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-6485-8781>),
  Meijun Chen [aut] (ORCID: <https://orcid.org/0000-0003-2486-8106>)
Maintainer: Guangchuang Yu <guangchuangyu@gmail.com>
