# Generated by roxygen2: do not edit by hand

export(enrichCOG)
export(enrichHMDB)
export(enrichKO)
export(enrichMBKEGG)
export(enrichMDA)
export(enrichModule)
export(enrichSMPDB)
export(gseCOG)
export(gseHMDB)
export(gseKO)
export(gseMBKEGG)
export(gseMDA)
export(gseModule)
export(gseSMPDB)
export(run_MicrobiomeProfiler)
import(shiny)
importFrom(DT,DTOutput)
importFrom(DT,JS)
importFrom(DT,datatable)
importFrom(DT,renderDT)
importFrom(enrichit,gsea_gson)
importFrom(enrichit,ora_gson)
importFrom(enrichplot,dotplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,guide_colorbar)
importFrom(ggplot2,guides)
importFrom(ggplot2,scale_color_gradient)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,xlab)
importFrom(golem,activate_js)
importFrom(golem,add_resource_path)
importFrom(golem,bundle_resources)
importFrom(golem,favicon)
importFrom(golem,with_golem_options)
importFrom(graphics,barplot)
importFrom(gson,gson)
importFrom(magrittr,"%<>%")
importFrom(methods,"slot<-")
importFrom(shiny,NS)
importFrom(shiny,shinyApp)
importFrom(shiny,tagList)
importFrom(shinyWidgets,colorPickr)
importFrom(shinycustomloader,withLoader)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(utils,data)
importFrom(utils,download.file)
importFrom(yulab.utils,yread)
