#' @title Example data: a vector of 134 significantly different functional
#' COGs between Psoriasis patients and controls
#'
#' @description This example data was
#' reported on Xiao S,et al.2021 (doi:10.3389/fcimb.2021.605825) and used for
#' COG enrichment analysis.
#'
#' @name Psoriasis_data
#' @aliases Psoriasis_data
#' @format a vector with 134 COGs
#' @docType data
#' @keywords data
#' @returns \url{https://www.frontiersin.org
#' /articles/10.3389/fcimb.2021.605825/full}
#' @examples
#' data(Psoriasis_data)
NA

#' @title Example data: a vector of 91 KEGG Orthologies (KOs) showing
#' significant associations with weaning weight
#'
#' @description This example data was reported on
#' Fang S,et al.2019 (doi: 10.1111/1751-7915.13485) and used for KEGG
#' enrichment analysis.
#'
#' @name Rat_data
#' @aliases Rat_data
#' @format a vector with 91 KEGG Orthologies (KOs)
#' @docType data
#' @keywords data
#' @references \url{https://sfamjournals.onlinelibrary.wiley.com
#' /doi/10.1111/1751-7915.13485}
#' @examples
#' data(Rat_data)
NA

#' @title Example data: a vector of 54 bacterial genera tested for significantly
#' between T2D metformin samples
#'
#' @description This example data was reported
#' on Forslund K,et al.2016 (doi: 10.1038/nature15766) and used for
#' Microbe-Disease Association analysis.
#'
#' @name microbiota_taxlist
#' @aliases microbiota_data
#' @format a vector with 54 genera tax ids
#' @docType data
#' @keywords data
#' @references \url{https://www.nature.com/articles/nature15766}
#' @examples
#' data(microbiota_taxlist)
NA

